***************************************************************************
***************************************************************************
***                                                                     ***
***                      3-dimensional, Open-drain                      ***
***                     Behavioral I/O Buffer Model                     ***
***                    Intel Corporation,  Folsom CA                    ***
***                                                                     ***
***************************************************************************
* COPYRIGHT 1995 Intel Corporation                     Intel Confidential *
***************************************************************************
* Filename: OD3D2_2.INC                                                   *
* Version:  2.2                                                           *
* Call As:  Xxxx Input Output Vcc Gnd Enable OD3D2_2                      *
* Polarity: Non-Inverting                                                 *
* Enable:   Active-High                                                   *
* Notes:    This is a model that incorporates data from an IBIS_2.0 file. *
*           To model another device, parameters can be changed by editing *
*           the proper sections below.  The diodes of this model do not   *
*           simulate the charge storage effects of real components.       *
***************************************************************************
* Component:   chip_name                                                  *
* Buffer Type: Open-drain, Fast                                           *
* Signals:     signal_name                                                *
***************************************************************************
***************************************************************************
.SUBCKT OD3D2_2 100 200 300 400 500
+ Co_comp    =  4.00pF    $ Output capacitance on die
+ Co_pkg     =  2.00pF    $ Package capacitance on output
+ Lo_pkg     = 10.00nH    $ Bond wire & pin inductance on output
+ Ro_pkg     =  0.200     $ Bond wire & pin resistance on output
+ Kiv_pd     =  1.0       $ Current scaling factor for pulldown I-V curves
+ Kvt_pd_on  =  1.0       $ Time scaling factor for pulldown on V-T curves
+ Kvt_pd_off =  1.0       $ Time scaling factor for pulldown off V-T curves
*-------------------------------------------------------------------------*
* Pin 100 is Input
* Pin 200 is Output (non-inverting)
* Pin 300 is Vcc
* Pin 400 is Gnd
* Pin 500 is Enable (active high)
*
******************************************* Parameters & Initial conditions
*
.PARAM Vinl = 0.80V                $ Input low threshold voltage
.PARAM Vinh = 2.00V                $ Input high threshold voltage
.PARAM Vmid = PAR('(Vinh+Vinl)/2') $ Midpoint between Vinl & Vinh
.PARAM Vdif = PAR('(Vinh-Vinl)/2') $ Difference between midpoint & Vinl
.PARAM Mult = PAR('2/(Vinh-Vinl)') $ Multiplying factor for a "0" & "1"
.PARAM Trip = 1e-9                 $ Switching error for Vinl & Vinh
.PARAM Rfixt_f = 25                $ R of test fixture falling waveform
.PARAM Vfixt_f = 1.50V             $ V of test fixture falling waveform
*
.PARAM Vpow     = 3.30V            $ Typical value of [Voltage Range]
.PARAM Kvcc_pd  = PAR('1/Vpow')    $ Vcc scaling factor for pulldown IV curve
*
********************************** Input & Enable threshold with hysteresis
*                                         in=100 en=500 drv_inv=140 drv=141
*
Vmid_hist 430 400 DC=Vmid
Esw_hist  130 430 PWL(1) 100 130
+ '(-1*Trip)' ,      Vdif
+      Trip   , '(-1*Vdif)'
*
Een_hist 530 430 PWL(1) 500 130
+ '(-1*Trip)' ,      Vdif
+      Trip   , '(-1*Vdif)'
*
Edrv_inv 140 0
+ VOL='min(1-max(0,min(1,Mult*V(530,430))),max(0,min(1,Mult*V(130,430))))'
Edrv     141 0
+ VOL='min(1-max(0,min(1,Mult*V(530,430))),1-max(0,min(1,Mult*V(130,430))))'
*
Rdum1 140 0 1000Meg
Rdum2 141 0 1000Meg
*
********************************************************* Time for pulldown
*                                                 in=140 on_t=930 off_t=921
*                                                                  & pullup
*                                                 in=141 on_t=931 off_t=920
Etime 900 0 VCVS VOL='TIME'
*
Rhi_lo1 900 910 R='1.001e-5 + abs(V(140,0)*1e+15)'
Chi_lo1 910   0 10fF
Ehi_lo1 920   0 VCVS 900 910 Kvt_pd_on min=0V
Rhi_lo2 920 930 R='1.001e-5 + abs(V(141,0)*1e+15)'
Chi_lo2 930   0 10fF
*
Rlo_hi1 900 911 R='1.001e-5 + abs(V(141,0)*1e+15)'
Clo_hi1 911   0 10fF
Elo_hi1 921   0 VCVS 900 911 Kvt_pd_off min=0V
Rlo_hi2 921 931 R='1.001e-5 + abs(V(140,0)*1e+15)'
Clo_hi2 931   0 10fF
*
*********************************************************** Output pulldown
*
.SUBCKT IV_CURVE_PD 1200 1000 1100 1400
Epwl_iv_pd 1200 1000 VCVS PWL(1) 1100 1400 $ delta='1/16'
+       -2.000          0.000000
+       -1.900        -11.700000m
+       -1.800        -23.100000m
+       -1.700        -34.200000m
+       -1.600        -44.900000m
+       -1.500        -55.000000m
+       -1.400        -64.400000m
+       -1.300        -72.700000m
+       -1.200        -79.300000m
+       -1.100        -82.900000m
+       -1.000        -79.900000m
+     -900.000m      -124.000000m
+     -800.000m      -124.000000m
+     -700.000m      -110.000000m
+     -600.000m       -94.600000m
+     -500.000m       -79.100000m
+     -400.000m       -63.500000m
+     -300.000m       -47.800000m
+     -100.000m       -16.000000m
+        0.000          0.000000
+      100.000m        15.900000m
+      200.000m        31.500000m
+      300.000m        46.800000m
+      400.000m        61.700000m
+      500.000m        76.200000m
+      600.000m        90.200000m
+      700.000m       104.000000m
+      900.000m       128.000000m
+        1.100        150.000000m
+        1.200        159.000000m
+        1.400        175.000000m
+        1.500        181.000000m
+        1.600        186.000000m
+        1.700        190.000000m
+        1.800        193.000000m
+        2.000        197.000000m
+        2.600        203.000000m
+        2.700        203.000000m
+        2.800        204.000000m
+        2.900        204.000000m
+        3.000        205.000000m
+        3.200        205.000000m
+        3.300        206.000000m
+        3.600        206.000000m
+        3.700        207.000000m
+        5.000        207.000000m
.ENDS
Epwl_on_pd 240 0 VCVS PWL(1) 930 0 $ delta='1/16'
+        0.000          1.500000
+       10.000p         1.499000
+       40.000p         1.493000
+       80.000p         1.482000
+      100.000p         1.475000
+      150.000p         1.455000
+      180.000p         1.441000
+      210.000p         1.426000
+      250.000p         1.404000
+      310.000p         1.368000
+      350.000p         1.342000
+      420.000p         1.292000
+      480.000p         1.244000
+      500.000p         1.227000
+      550.000p         1.182000
+      590.000p         1.144000
+      680.000p         1.053000
+      770.000p       958.000000m
+      870.000p       858.000000m
+      910.000p       820.000000m
+      990.000p       748.000000m
+        1.030n       714.000000m
+        1.120n       643.000000m
+        1.190n       594.000000m
+        1.240n       562.000000m
+        1.280n       539.000000m
+        1.340n       509.000000m
+        1.390n       489.000000m
+        1.460n       467.000000m
+        1.520n       452.000000m
+        1.610n       434.000000m
+        1.670n       424.000000m
+        1.710n       419.000000m
+        1.740n       414.000000m
+        1.900n       396.000000m
+        1.920n       395.000000m
+        2.040n       384.000000m
+        2.200n       373.000000m
+        2.450n       360.000000m
+        2.470n       360.000000m
+        2.600n       354.000000m
+        2.840n       346.000000m
+        2.870n       346.000000m
+        2.910n       344.000000m
+        2.940n       344.000000m
+        2.950n       343.000000m
+        3.060n       341.000000m
+        3.070n       340.000000m
+        3.100n       340.000000m
+        3.110n       339.000000m
+        3.150n       339.000000m
+        3.200n       337.000000m
+        3.290n       336.000000m
+        3.350n       334.000000m
+        3.390n       334.000000m
+        3.400n       333.000000m
+        3.450n       333.000000m
+        3.460n       332.000000m
+        3.510n       332.000000m
+        3.520n       331.000000m
+        3.570n       331.000000m
+        3.580n       330.000000m
+        3.630n       330.000000m
+        3.640n       329.000000m
+        3.770n       328.000000m
+        3.780n       327.000000m
+        3.840n       327.000000m
+        3.850n       326.000000m
+        3.920n       326.000000m
+        3.930n       325.000000m
+        4.010n       325.000000m
+        4.020n       324.000000m
+        4.100n       324.000000m
+        4.110n       323.000000m
+        4.190n       323.000000m
+        4.200n       322.000000m
+        4.400n       321.000000m
+        4.410n       320.000000m
+        4.520n       320.000000m
+        4.530n       319.000000m
+        4.640n       319.000000m
+        4.650n       318.000000m
+        4.780n       318.000000m
+        4.790n       317.000000m
+        4.930n       317.000000m
+        4.940n       316.000000m
+        5.090n       316.000000m
+        5.100n       315.000000m
+        5.480n       314.000000m
+        5.490n       313.000000m
+        5.980n       312.000000m
+        5.990n       311.000000m
+        6.290n       311.000000m
+        6.300n       310.000000m
+        6.660n       310.000000m
+        6.670n       309.000000m
+        7.700n       308.000000m
+        7.710n       307.000000m
+        8.540n       307.000000m
+        8.550n       306.000000m
Epwl_off_pd 250 0 VCVS PWL(1) 921 0 $ delta='1/16'
+        0.000        306.000000m
+       20.000p       308.000000m
+       30.000p       308.000000m
+       70.000p       314.000000m
+      100.000p       322.000000m
+      130.000p       334.000000m
+      150.000p       346.000000m
+      170.000p       362.000000m
+      180.000p       372.000000m
+      200.000p       390.000000m
+      220.000p       404.000000m
+      230.000p       409.000000m
+      260.000p       418.000000m
+      290.000p       424.000000m
+      430.000p       445.000000m
+      510.000p       461.000000m
+      610.000p       486.000000m
+      660.000p       501.000000m
+      670.000p       505.000000m
+      690.000p       511.000000m
+      750.000p       533.000000m
+      760.000p       538.000000m
+      790.000p       550.000000m
+      800.000p       555.000000m
+      830.000p       567.000000m
+      840.000p       572.000000m
+      940.000p       612.000000m
+      950.000p       615.000000m
+        1.000n       634.000000m
+        1.080n       662.000000m
+        1.100n       668.000000m
+        1.130n       679.000000m
+        1.200n       701.000000m
+        1.210n       705.000000m
+        1.240n       714.000000m
+        1.250n       718.000000m
+        1.270n       724.000000m
+        1.350n       752.000000m
+        1.430n       783.000000m
+        1.440n       788.000000m
+        1.490n       809.000000m
+        1.510n       819.000000m
+        1.520n       823.000000m
+        1.610n       868.000000m
+        1.620n       874.000000m
+        1.650n       889.000000m
+        1.680n       906.000000m
+        1.700n       916.000000m
+        1.720n       928.000000m
+        1.730n       933.000000m
+        1.750n       945.000000m
+        1.760n       950.000000m
+        1.830n       992.000000m
+        1.840n       999.000000m
+        1.860n         1.011000
+        1.920n         1.050000
+        1.940n         1.064000
+        1.950n         1.070000
+        2.000n         1.104000
+        2.010n         1.110000
+        2.040n         1.131000
+        2.050n         1.137000
+        2.070n         1.151000
+        2.100n         1.170000
+        2.120n         1.184000
+        2.160n         1.210000
+        2.180n         1.222000
+        2.190n         1.229000
+        2.210n         1.241000
+        2.220n         1.248000
+        2.320n         1.308000
+        2.370n         1.335000
+        2.380n         1.341000
+        2.400n         1.351000
+        2.410n         1.357000
+        2.450n         1.377000
+        2.460n         1.381000
+        2.480n         1.391000
+        2.500n         1.400000
+        2.580n         1.432000
+        2.600n         1.438000
+        2.610n         1.442000
+        2.660n         1.457000
+        2.680n         1.462000
+        2.700n         1.467000
+        2.750n         1.477000
+        2.790n         1.483000
+        2.880n         1.492000
+        2.890n         1.492000
+        2.910n         1.494000
+        2.950n         1.495000
+        2.960n         1.496000
+        2.980n         1.496000
+        2.990n         1.497000
+        3.030n         1.497000
+        3.040n         1.498000
+        3.120n         1.498000
+        3.130n         1.499000
+        3.590n         1.499000
+        3.600n         1.500000
*
Ewav_pd  260 0 VOL='max(V(240,0),V(250,0))'
Cwav_pd  260 0 Co_comp
Xiv_pd_1 270 0 260   0 IV_CURVE_PD
Xiv_pd_2 280 0 220 400 IV_CURVE_PD
Emath_pd 290 400
+ VOL='Kvcc_pd*V(300,400)*Kiv_pd*V(280,0)*(Vfixt_f-V(260,0))/(Rfixt_f*V(270,0))-I(Cwav_pd)'
*Gadj_pd  220 400 VCCS 290 220 1
*Rout_pd  220 400 1
Rout_pd  220 221 1
Eadj_pd  221 400 VCCS 220 290 1
*
******************************************************* Output clamp to GND
*
Ggnd_out 220 400 VCCS PWL(1) 220 400 $ delta='1/16'
+       -2.000         -1.120000
+       -1.900         -1.010000
+       -1.800       -907.000000m
+       -1.700       -802.000000m
+       -1.600       -696.000000m
+       -1.500       -591.000000m
+       -1.400       -487.000000m
+       -1.300       -384.000000m
+       -1.200       -283.000000m
+       -1.100       -184.000000m
+       -1.000        -92.700000m
+     -900.000m       -21.600000m
+     -800.000m        -1.160000m
+     -700.000m       -77.700000u
+     -600.000m        -4.660000u
+     -500.000m      -300.000000n
+     -400.000m       -20.600000n
+     -300.000m        -1.520000n
+     -200.000m      -120.000000p
+     -100.000m       -10.400000p
+        0.000          0.000000
+      100.000m         1.060000p
+      200.000m         1.180000p
+      300.000m         1.290000p
+      400.000m         1.370000p
+      500.000m         1.520000p
+      600.000m         1.620000p
+      700.000m         1.640000p
+      800.000m         1.790000p
+      900.000m         1.820000p
+        1.000          1.930000p
+        1.100          1.980000p
+        1.200          2.020000p
+        1.300          2.070000p
+        1.400          2.130000p
+        1.500          2.290000p
+        1.600          2.380000p
+        1.700          2.330000p
+        1.800          2.420000p
+        1.900          2.460000p
+        2.000          2.490000p
+        2.200          2.750000p
+        2.300          2.710000p
+        2.400          2.750000p
+        2.500          2.890000p
+        2.600          3.060000p
+        2.700          3.110000p
+        2.800          3.110000p
+        2.900          3.240000p
+        3.000          3.460000p
+        3.100          3.290000p
+        3.200          3.330000p
+        3.300          3.550000p
+        3.400          3.600000p
+        5.000          3.600000p
*
******************************************************* Output clamp to Vcc
*
Gvcc_out 220 300 VCCS PWL(1) 300 220 $ delta='1/16'
+       -1.800        130.000000m
+       -1.750        122.000000m
+       -1.650        108.000000m
+       -1.600        100.000000m
+       -1.350         63.500000m
+       -1.250         49.100000m
+       -1.200         42.000000m
+       -1.150         35.000000m
+       -1.100         28.100000m
+       -1.050         21.500000m
+       -1.000         15.100000m
+     -950.000m         9.200000m
+     -900.000m         4.290000m
+     -850.000m         1.210000m
+     -800.000m       191.000000u
+     -700.000m         2.880000u
+     -600.000m        41.300000n
+     -500.000m       594.000000p
+     -400.000m        12.300000p
+     -300.000m         3.820000p
+     -200.000m         3.600000p
+     -100.000m         3.550000p
+        0.000          0.000000
*
************************************************************ Output package
*
*Rshort 200 220 1.0 M=1e+6
Cout_pkg 200 400 Co_pkg
Rout_pkg 200 210 Ro_pkg
Lout_pkg 210 220 Lo_pkg
*Rout_snb 210 220 100
*
Cout_die 220 400 Co_comp
*
***************************************************************************
.ENDS OD3D2_2
***************************************************************************
